# pyetymdict

[![Build Status](https://github.com/lexibank/pyetymdict/workflows/tests/badge.svg)](https://github.com/lexibank/pyetymdict/actions?query=workflow%3Atests)
[![PyPI](https://img.shields.io/pypi/v/pyetymdict.svg)](https://pypi.org/project/pyetymdict)

The package provides a CLDF data model for etymological dictionaires layered on top of CLDF Wordlists 
curated via `pylexibank` and a [cldfbench](https://github.com/cldf/cldfbench) subcommand to display
complex cognate sets from such datasets.

![](etymdict.set.png)
